==> neo4j-cypher-2.2.5-sources.jar: org/neo4j/cypher/javacompat/internal/CypherEngineProvider.java <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.javacompat.internal;

import org.neo4j.helpers.Service;
import org.neo4j.kernel.GraphDatabaseAPI;
import org.neo4j.kernel.impl.query.QueryEngineProvider;
import org.neo4j.kernel.impl.query.QueryExecutionEngine;
import org.neo4j.kernel.logging.Logging;

@Service.Implementation(QueryEngineProvider.class)
public class CypherEngineProvider extends QueryEngineProvider
{
    public CypherEngineProvider()
    {
        super( "cypher" );
    }

    @Override
    protected QueryExecutionEngine createEngine( GraphDatabaseAPI graphAPI )
    {
        Logging logging = graphAPI.getDependencyResolver().resolveDependency( Logging.class );
        return new ServerExecutionEngine( graphAPI, logging.getMessagesLog( QueryExecutionEngine.class ) );
    }
}

==> neo4j-cypher-2.3.0-sources.jar: org/neo4j/cypher/javacompat/internal/CypherEngineProvider.java <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.javacompat.internal;

import org.neo4j.helpers.Service;
import org.neo4j.kernel.GraphDatabaseAPI;
import org.neo4j.kernel.impl.logging.LogService;
import org.neo4j.kernel.impl.query.QueryEngineProvider;
import org.neo4j.kernel.impl.query.QueryExecutionEngine;

@Service.Implementation(QueryEngineProvider.class)
public class CypherEngineProvider extends QueryEngineProvider
{
    public CypherEngineProvider()
    {
        super( "cypher" );
    }

    @Override
    protected QueryExecutionEngine createEngine( GraphDatabaseAPI graphAPI )
    {
        LogService logService = graphAPI.getDependencyResolver().resolveDependency( LogService.class );
        return new ServerExecutionEngine( graphAPI, logService.getInternalLogProvider() );
    }
}
